@@ -1,15 +1,13 @@
 -- Minetest: builtin/static_spawn.lua
 
-local function warn_invalid_static_spawnpoint()
-	if core.settings:get("static_spawnpoint") and
-			not core.setting_get_pos("static_spawnpoint") then
-		core.log("error", "The static_spawnpoint setting is invalid: \""..
-				core.settings:get("static_spawnpoint").."\"")
-	end
+local static_spawnpoint_string = core.settings:get("static_spawnpoint")
+if static_spawnpoint_string and
+		static_spawnpoint_string ~= "" and
+		not core.setting_get_pos("static_spawnpoint") then
+	error('The static_spawnpoint setting is invalid: "' ..
+			static_spawnpoint_string .. '"')
 end
 
-warn_invalid_static_spawnpoint()
-
 local function put_player_in_spawn(player_obj)
 	local static_spawnpoint = core.setting_get_pos("static_spawnpoint")
 	if not static_spawnpoint then
@@ -17,7 +15,7 @@ local function put_player_in_spawn(player_obj)
 	end
 	core.log("action", "Moving " .. player_obj:get_player_name() ..
 		" to static spawnpoint at " .. core.pos_to_string(static_spawnpoint))
-	player_obj:setpos(static_spawnpoint)
+	player_obj:set_pos(static_spawnpoint)
 	return true
 end
 
